import json

import asynctest
from aiohttp import web
from aiohttp.test_utils import AioHTTPTestCase, unittest_run_loop
from src.pyodstibmivb.odstibmivb import HttpException, ODStibMivb
from tests import mock_requests

API_KEY = "2133c416f69f5acaa67351501153d892"
CONTENT_TYPE = "application/json"


def ordered(obj):
    if isinstance(obj, dict):
        return sorted((k, ordered(v)) for k, v in obj.items())
    if isinstance(obj, list):
        return sorted(ordered(x) for x in obj)
    else:
        return obj


class TestODStibMivb(AioHTTPTestCase):
    async def get_application(self):
        """
        Override the get_app method to return your application.
        """

        async def vehicle_position_1(request):
            response = mock_requests.Response(request.url.path, request.headers)
            return web.Response(
                text=response.text, status=response.status, content_type=CONTENT_TYPE
            )

        app = web.Application()
        app.router.add_get("/{tail:.+}", vehicle_position_1)
        return app

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_vehicle_position_single(self):
        result = await ODStibMivb(API_KEY, self.client).get_vehicle_position("1")
        self.assertEqual(
            ordered(result), ordered(json.loads(mock_requests.VEHICLE_POSITION_1))
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_vehicle_position_single_int(self):
        result = await ODStibMivb(API_KEY, self.client).get_vehicle_position(1)
        self.assertEqual(
            ordered(result), ordered(json.loads(mock_requests.VEHICLE_POSITION_1))
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_vehicle_position_multiple(self):
        result = await ODStibMivb(API_KEY, self.client).get_vehicle_position("1", "5")
        self.assertEqual(
            ordered(result), ordered(json.loads(mock_requests.VEHICLE_POSITION_1_5))
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_vehicle_position_multiple_int(self):
        result = await ODStibMivb(API_KEY, self.client).get_vehicle_position(1, 5)
        self.assertEqual(
            ordered(result), ordered(json.loads(mock_requests.VEHICLE_POSITION_1_5))
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_waiting_time_single(self):
        result = await ODStibMivb(API_KEY, self.client).get_waiting_time("8301")
        self.assertEqual(
            ordered(result), ordered(json.loads(mock_requests.WAITING_TIME_8301))
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_waiting_time_multiple(self):
        result = await ODStibMivb(API_KEY, self.client).get_waiting_time("8301", "8302")
        self.assertEqual(
            ordered(result), ordered(json.loads(mock_requests.WAITING_TIME_8301_8302))
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_message_by_line_single(self):
        result = await ODStibMivb(API_KEY, self.client).get_message_by_line("12")
        self.assertEqual(
            ordered(result), ordered(json.loads(mock_requests.MESSAGE_BY_LINE_12))
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_message_by_line_multiple(self):
        result = await ODStibMivb(API_KEY, self.client).get_message_by_line("12", "17")
        self.assertEqual(
            ordered(result), ordered(json.loads(mock_requests.MESSAGE_BY_LINE_12_17))
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_stops_by_line_single(self):
        result = await ODStibMivb(API_KEY, self.client).get_stops_by_line("1")
        self.assertEqual(
            ordered(result), ordered(json.loads(mock_requests.STOPS_BY_LINE_1))
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_stops_by_line_multiple(self):
        result = await ODStibMivb(API_KEY, self.client).get_stops_by_line("1", "5")
        self.assertEqual(
            ordered(result), ordered(json.loads(mock_requests.STOPS_BY_LINE_1_5))
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_point_detail_single(self):
        result = await ODStibMivb(API_KEY, self.client).get_point_detail("8301")
        self.assertEqual(
            ordered(result), ordered(json.loads(mock_requests.POINT_DETAIL_8301))
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_point_detail_multiple(self):
        result = await ODStibMivb(API_KEY, self.client).get_point_detail(
            "8301", "0470F"
        )
        self.assertEqual(
            ordered(result), ordered(json.loads(mock_requests.POINT_DETAIL_8301_0470F))
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_message_by_line_with_point_detail_single(self):
        result = await ODStibMivb(
            API_KEY, self.client
        ).get_message_by_line_with_point_detail("32")
        self.assertEqual(
            ordered(result["messages"][0]["content"]),
            ordered(
                json.loads(mock_requests.MESSAGE_BY_LINE_32)["messages"][0]["content"]
            ),
        )
        self.assertEqual(
            ordered(result["messages"][0]["priority"]),
            ordered(
                json.loads(mock_requests.MESSAGE_BY_LINE_32)["messages"][0]["priority"]
            ),
        )
        self.assertEqual(
            ordered(result["messages"][0]["priority"]),
            ordered(
                json.loads(mock_requests.MESSAGE_BY_LINE_32)["messages"][0]["priority"]
            ),
        )
        part1 = json.loads(mock_requests.POINT_DETAIL_10_ARGS_2903F_TO_5801)
        part2 = json.loads(mock_requests.POINT_DETAIL_10_ARGS_5714_TO_5712F)
        part3 = json.loads(mock_requests.POINT_DETAIL_10_ARGS_5711F_TO_626)
        part4 = json.loads(mock_requests.POINT_DETAIL_4_ARGS_5868_TO_636)
        self.assertEqual(
            ordered(result["messages"][0]["points"]),
            ordered(
                part1["points"] + part2["points"] + part3["points"] + part4["points"]
            ),
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_message_by_line_with_point_detail_multiple(self):
        result = await ODStibMivb(
            API_KEY, self.client
        ).get_message_by_line_with_point_detail("12", "32")
        self.assertEqual(
            ordered(result["messages"][0]["content"]),
            ordered(
                json.loads(mock_requests.MESSAGE_BY_LINE_12)["messages"][0]["content"]
            ),
        )
        self.assertEqual(
            ordered(result["messages"][0]["priority"]),
            ordered(
                json.loads(mock_requests.MESSAGE_BY_LINE_12)["messages"][0]["priority"]
            ),
        )
        self.assertEqual(
            ordered(result["messages"][0]["type"]),
            ordered(
                json.loads(mock_requests.MESSAGE_BY_LINE_12)["messages"][0]["type"]
            ),
        )
        self.assertEqual(
            ordered(result["messages"][0]["points"]),
            ordered(json.loads(mock_requests.POINT_DETAIL_6448)["points"]),
        )

        self.assertEqual(
            ordered(result["messages"][1]["content"]),
            ordered(
                json.loads(mock_requests.MESSAGE_BY_LINE_32)["messages"][0]["content"]
            ),
        )
        self.assertEqual(
            ordered(result["messages"][1]["priority"]),
            ordered(
                json.loads(mock_requests.MESSAGE_BY_LINE_32)["messages"][0]["priority"]
            ),
        )
        self.assertEqual(
            ordered(result["messages"][1]["priority"]),
            ordered(
                json.loads(mock_requests.MESSAGE_BY_LINE_32)["messages"][0]["priority"]
            ),
        )
        part1 = json.loads(mock_requests.POINT_DETAIL_10_ARGS_2903F_TO_5801)
        part2 = json.loads(mock_requests.POINT_DETAIL_10_ARGS_5714_TO_5712F)
        part3 = json.loads(mock_requests.POINT_DETAIL_10_ARGS_5711F_TO_626)
        part4 = json.loads(mock_requests.POINT_DETAIL_4_ARGS_5868_TO_636)
        self.assertEqual(
            ordered(result["messages"][1]["points"]),
            ordered(
                part1["points"] + part2["points"] + part3["points"] + part4["points"]
            ),
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_point_detail_incorrect_argument(self):
        with self.assertRaises(HttpException) as context_manager:
            await ODStibMivb(API_KEY, self.client).get_point_detail("/8301/")
        self.assertEqual(context_manager.exception.status_code, 403)

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_number_arguments_11(self):
        result = await ODStibMivb(API_KEY, self.client).get_point_detail(
            1, 2, 3, 4, 5, 6, 7, 8, 9, 15, 28
        )
        part1 = json.loads(mock_requests.POINT_DETAIL_10_ARGS)
        part2 = json.loads(mock_requests.POINT_DETAIL_28)
        self.assertEqual(
            ordered(result["points"]), ordered(part1["points"] + part2["points"])
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_number_arguments_10(self):
        result = await ODStibMivb(API_KEY, self.client).get_point_detail(
            1, 2, 3, 4, 5, 6, 7, 8, 9, 15
        )
        self.assertEqual(
            ordered(result), ordered(json.loads(mock_requests.POINT_DETAIL_10_ARGS))
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_point_detail_incorrect_formatted_key(self):
        with self.assertRaises(ValueError):
            await ODStibMivb("123456", self.client)

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_point_detail_incorrect_key(self):
        api_instance = ODStibMivb(API_KEY[:-1] + "9", self.client)
        with self.assertRaises(HttpException) as context_manager:
            await api_instance.get_point_detail("8301")
        self.assertEqual(context_manager.exception.status_code, 401)

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_invalid_method(self):
        api_instance = ODStibMivb(API_KEY, self.client)
        with self.assertRaises(ValueError):
            await api_instance.do_request("get_message_by_stop", "8301")

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_server_wrong_data(self):
        api_instance = ODStibMivb(API_KEY, self.client)
        with self.assertRaises(Exception) as context_manager:
            await api_instance.get_point_detail("123456")
        message = "Server gave incorrect data"
        self.assertEqual(str(context_manager.exception), message)

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_server_404_error(self):
        api_instance = ODStibMivb(API_KEY, self.client)
        with self.assertRaises(HttpException) as context_manager:
            await api_instance.get_point_detail("1234567")
        self.assertEqual(context_manager.exception.status_code, 404)

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_line_long_name_1(self):
        api_instance = ODStibMivb(API_KEY, self.client)
        self.assertEqual(
            api_instance.get_line_long_name("5"), "ERASME - HERRMANN-DEBROUX"
        )

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_line_long_name_2(self):
        api_instance = ODStibMivb(API_KEY, self.client)
        self.assertEqual(api_instance.get_line_long_name("76"), "KRAAINEM - OPPEM")

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_line_long_name_invalid_id(self):
        api_instance = ODStibMivb(API_KEY, self.client)
        with self.assertRaises(ValueError) as context_manager:
            await api_instance.get_line_long_name("1234")
        message = "unknown line id"
        self.assertEqual(str(context_manager.exception), message)

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_line_type_1(self):
        api_instance = ODStibMivb(API_KEY, self.client)
        self.assertEqual(api_instance.get_line_type("5"), "1")

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_line_type_2(self):
        api_instance = ODStibMivb(API_KEY, self.client)
        self.assertEqual(api_instance.get_line_type("88"), "3")

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_line_type_invalid_id(self):
        api_instance = ODStibMivb(API_KEY, self.client)
        with self.assertRaises(ValueError) as context_manager:
            await api_instance.get_line_type("21234")
        message = "unknown line id"
        self.assertEqual(str(context_manager.exception), message)

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_line_color_1(self):
        api_instance = ODStibMivb(API_KEY, self.client)
        self.assertEqual(api_instance.get_line_color("1"), "C4008F")

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_line_color_2(self):
        api_instance = ODStibMivb(API_KEY, self.client)
        self.assertEqual(api_instance.get_line_color("21"), "F7E017")

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_line_color_invalid_id(self):
        api_instance = ODStibMivb(API_KEY, self.client)
        with self.assertRaises(ValueError) as context_manager:
            await api_instance.get_line_color("2234")
        message = "unknown line id"
        self.assertEqual(str(context_manager.exception), message)

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_line_text_color_1(self):
        api_instance = ODStibMivb(API_KEY, self.client)
        self.assertEqual(api_instance.get_line_text_color("1"), "FFFFFF")

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_line_text_color_2(self):
        api_instance = ODStibMivb(API_KEY, self.client)
        self.assertEqual(api_instance.get_line_text_color("4"), "000000")

    @unittest_run_loop
    @asynctest.patch("src.pyodstibmivb.odstibmivb.URL", "/")
    async def test_get_line_text_color_invalid_id(self):
        api_instance = ODStibMivb(API_KEY, self.client)
        with self.assertRaises(ValueError) as context_manager:
            await api_instance.get_line_text_color("2238")
        message = "unknown line id"
        self.assertEqual(str(context_manager.exception), message)



import re

from setuptools import setup

with open("src/pyodstibmivb/__init__.py", "r") as fd:
    version = re.search(
        r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', fd.read(), re.MULTILINE
    ).group(1)

with open("README.md", "r") as f:
    long_description = f.read()

setup(
    name="pyodstibmivb",
    version=version,
    author="Emil Vanherp",
    author_email="emil@vanherp.me",
    description="A Python wrapper for the Stib-Mivb opendata API",
    license="MIT License",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitlab.com/EmilV2/pyodstibmivb",
    install_requires=["aiohttp==3.5.4"],
    python_requires=">=3",
    packages=["pyodstibmivb"],
    package_dir={"": "src"},
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



CSVFILE = """\
route_id,route_short_name,route_long_name,route_desc,route_type,route_url,route_color,route_text_color
2,1,"GARE DE L'OUEST - STOCKEL",,1,,C4008F,FFFFFF
3,2,"SIMONIS - ELISABETH",,1,,F57000,FFFFFF
5,3,"ESPLANADE - CHURCHILL",,0,,B5BA05,000000
8,4,"GARE DU NORD - STALLE (P)",,0,,F25482,000000
1,5,"ERASME - HERRMANN-DEBROUX",,1,,E6B012,FFFFFF
4,6,"ROI BAUDOUIN - ELISABETH",,1,,0078AD,FFFFFF
6,7,"VANDERKINDERE - HEYSEL",,0,,FFF06E,000000
11,8,"LOUISE - ROODEBEEK",,0,,00A1DF,000000
12,9,"SIMONIS - ARBRE BALLON",,0,,FF00FF,FFFFFF
71,12,"BRUSSELS AIRPORT - BRUSSELS CITY",,3,,338C26,FFFFFF
23,13,"SIMONIS - UZ-VUB",,3,,9EBFE3,000000
24,14,"GARE DU NORD - UZ-VUB",,3,,FF9EC2,000000
46,17,"BEAULIEU - HEILIGENBORRE",,3,,DE3B21,FFFFFF
13,19,"GROOT-BIJGAARDEN - DE WAND",,0,,DE3B21,FFFFFF
25,20,"HUNDERENVELD - GARE DU NORD",,3,,E3BA12,000000
70,21,"BRUSSELS AIRPORT - LUXEMBOURG",,3,,F7E017,000000
16,25,"BOONDAEL GARE - ROGIER",,0,,991F36,FFFFFF
47,27,"GARE DU MIDI - ANDROMEDE",,3,,9EBFE3,000000
48,28,"BRABANCONNE - KONKEL",,3,,DE3B21,FFFFFF
72,29,"DE BROUCKERE - HOF TEN BERG",,3,,E87D0D,FFFFFF
22,32,"DA VINCI - DROGENBOS CHATEAU",,0,,F7E017,000000
27,33,"DANSAERT - LOUISE",,3,,FF9EC2,000000
49,34,"PORTE DE NAMUR - SAINTE-ANNE",,3,,E3BA12,000000
50,36,"SCHUMAN - KONKEL",,3,,9EBFE3,000000
28,37,"ALBERT - GARE DE LINKEBEEK",,3,,36578C,FFFFFF
51,38,"GARE CENTRALE - HEROS",,3,,B085B3,FFFFFF
19,39,"MONTGOMERY - BAN-EIK",,0,,DE3B21,FFFFFF
52,41,"HEROS - TRANSVAAL",,3,,9EBFE3,000000
64,42,"VIADUC E40 - ROODEBEEK",,3,,338C26,FFFFFF
29,43,"OBSERVATOIRE - VIVIER D'OIE",,3,,996308,FFFFFF
18,44,"MONTGOMERY - TERVUREN STATION",,0,,E3BA12,000000
65,45,"ROODEBEEK - SAINT-VINCENT",,3,,B085B3,FFFFFF
30,46,"MOORTEBEEK - ANNEESSENS",,3,,DE3B21,FFFFFF
66,47,"DE BROUCKERE - VILVOORDE STATION",,3,,B085B3,FFFFFF
84,48,"GRAND-PLACE - DECROLY",,3,,338C26,FFFFFF
32,49,"GARE DU MIDI - BOCKSTAEL",,3,,36578C,FFFFFF
33,50,"GARE DU MIDI - LOT STATION",,3,,B5BA05,000000
14,51,"STADE - VAN HAELEN",,0,,E3BA12,000000
76,53,"HOPITAL MILITAIRE - UZ-VUB",,3,,338C26,FFFFFF
34,54,"TRONE - FOREST (BERVOETS)",,3,,DE3B21,FFFFFF
17,55,"DA VINCI - ROGIER",,0,,E3BA12,000000
75,57,"GARE DU NORD - HOPITAL MILITAIRE",,3,,DE3B21,FFFFFF
67,58,"VILVOORDE STATION - YSER",,3,,338C26,FFFFFF
68,59,"HOPITAL ETTERBEEK-IXELLES - BORDET STATION",,3,,996308,FFFFFF
53,60,"AMBIORIX - UCCLE CALEVOET",,3,,FF9EC2,000000
54,61,"GARE DU NORD - MONTGOMERY",,3,,F7E017,000000
7,62,"EUROCONTROL - CIMETIERE DE JETTE",,0,,FF9EC2,000000
77,63,"GARE CENTRALE - CIMETIERE DE BRUXELLES",,3,,9EBFE3,000000
79,64,"PORTE DE NAMUR - MACHELEN",,3,,DE3B21,FFFFFF
78,65,"GARE CENTRALE - BOURGET",,3,,E3BA12,000000
73,66,"DE BROUCKERE - PEAGE",,3,,36578C,FFFFFF
74,69,"SCHAERBEEK GARE - JULES BORDET",,3,,E87D0D,FFFFFF
55,71,"DE BROUCKERE - DELTA",,3,,338C26,FFFFFF
56,72,"ULB - ADEPS",,3,,FF9EC2,000000
35,75,"CAMPUS CERIA - BON AIR",,3,,F7E017,000000
57,76,"KRAAINEM - OPPEM",,3,,F7E017,000000
58,77,"KRAAINEM - HIPPODROME",,3,,338C26,FFFFFF
85,78,"HUMANITE - GARE DU MIDI",,3,,B085B3,FFFFFF
69,79,"KRAAINEM - SCHUMAN",,3,,36578C,FFFFFF
59,80,"PORTE DE NAMUR - MAES",,3,,338C26,FFFFFF
20,81,"MARIUS RENARD - MONTGOMERY",,0,,338C26,FFFFFF
15,82,"BERCHEM STATION - DROGENBOS CHATEAU",,0,,9EBFE3,000000
37,84,"BERCHEM STATION - HEYSEL",,3,,F7E017,000000
38,86,"MACHTENS - GARE CENTRALE",,3,,338C26,FFFFFF
26,87,"SIMONIS - BEEKKANT",,3,,338C26,FFFFFF
39,88,"DE BROUCKERE - HEYSEL",,3,,991F36,FFFFFF
31,89,"WESTLAND SHOPPING - BOCKSTAEL",,3,,E87D0D,FFFFFF
9,92,"SCHAERBEEK GARE - FORT-JACO",,0,,DE3B21,FFFFFF
21,93,"STADE - LEGRAND",,0,,E87D0D,FFFFFF
60,95,"GRAND-PLACE - WIENER",,3,,36578C,FFFFFF
10,97,"LOUISE - DIEWEG",,0,,991F36,FFFFFF
36,98,"CERIA - HEROS",,3,,FC8306,FFFFFF
45,T32,"DA VINCI - DROGENBOS CHATEAU",,3,,F7E017,000000
83,T55,"DA VINCI - ROGIER",,3,,E3BA12,000000
86,T81,"MARIUS RENARD - MONTGOMERY",,3,,338C26,FFFFFF
44,T82,"BERCHEM STATION - DROGENBOS CHATEAU",,3,,9EBFE3,000000
63,T92,"SCHAERBEEK GARE - FORT-JACO",,3,,DE3B21,FFFFFF
81,N04,"GARE CENTRALE - CIMETIERE DE BRUXELLES",,3,,FF00FF,FFFFFF
82,N05,"GARE CENTRALE - KRAAINEM",,3,,9978B8,FFFFFF
80,N06,"GARE CENTRALE - MUSEE DU TRAM",,3,,00C8FF,FFFFFF
61,N08,"GARE CENTRALE - WIENER",,3,,94C9FD,000000
62,N09,"GARE CENTRALE - HERRMANN-DEBROUX",,3,,FF00FF,FFFFFF
40,N10,"GARE CENTRALE - FORT-JACO",,3,,D2FF0A,000000
87,N11,"GARE CENTRALE - HOMBORCH",,3,,976A0E,FFFFFF
42,N12,"GARE CENTRALE - CARREFOUR STALLE",,3,,FC8306,FFFFFF
88,N13,"GARE CENTRALE - WESTLAND SHOPPING",,3,,C30C3E,FFFFFF
43,N16,"GARE CENTRALE - BERCHEM STATION",,3,,0A3C0A,FFFFFF
41,N18,"GARE CENTRALE - HEYSEL",,3,,64D214,FFFFFF
"""
